==> dde-launchpad_1.99.0.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Закрепить сверху</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Добавить в избранное</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Отправить на рабочий стол</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Удалить с рабочего стола</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Убрать из дока</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Отправить в док</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Добавить в автозагрузку</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Удалить из автозагрузки</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Использовать прокси</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Отключить маштабирование дисплея</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation>Питание</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="103"/>
        <source>Full-screen Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Часто используемое</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="152"/>
        <source>Window Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <source>Show launcher (hidden by default)</source>
        <translation type="vanished">Показать панель запуска (скрыта по умолчанию)</translation>
    </message>
    <message>
        <source>Toggle launcher visibility</source>
        <translation type="vanished">Переключить видимость программы запуска</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Интернет</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Графика</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation>Игра</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Офис</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Чтение</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Разработка</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Прочее</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Вы уверены, что хотите удалить %1?</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Недавно установленное</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Все приложения</translation>
    </message>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="545"/>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Ничего не найдено</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Свободная сортировка</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Сортировать по категориям</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Сортировать по имени</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Компьютер</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Картинки</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Документы</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Рабочий Стол</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Центр управления</translation>
    </message>
</context>
</TS>

==> dde-launchpad_1.99.1.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Закрепить сверху</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Добавить в избранное</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Отправить на рабочий стол</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Удалить с рабочего стола</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Убрать из дока</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Отправить в док</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Добавить в автозагрузку</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Удалить из автозагрузки</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Использовать прокси</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Отключить маштабирование дисплея</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation>Питание</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="103"/>
        <source>Full-screen Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Часто используемое</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="152"/>
        <source>Window Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Показать панель запуска (скрыта по умолчанию)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Переключить видимость программы запуска</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Интернет</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Графика</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation>Игра</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Офис</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Чтение</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Разработка</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Прочее</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Вы уверены, что хотите удалить %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Недавно установленное</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Все приложения</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="545"/>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Ничего не найдено</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Свободная сортировка</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Сортировать по категориям</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Сортировать по имени</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Компьютер</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Картинки</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Документы</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Рабочий Стол</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Центр управления</translation>
    </message>
</context>
</TS>
